TDDivider class

分割线 对于非flutter原有的控件,则只需满足TDesign规范即可; 如果有业务在实际使用,还需兼容实际业务场景。

Inheritance

Constructors

TDDivider({Key? key, Color? color, EdgeInsetsGeometry? margin, double? width, double? height, String? text, Widget? widget, EdgeInsetsGeometry? gapPadding, bool hideLine = false, bool isDashed = false, TextAlignment alignment = TextAlignment.center, Axis direction = Axis.horizontal})
const

Properties

alignment TextAlignment
文字位置
final
color Color?
线条颜色
final
direction Axis
方向,竖直虚线必须传
final
gapPadding EdgeInsetsGeometry?
线条和中间文本之间的填充
final
hashCode int
The hash code for this object.
no setterinherited
height double?
高度,横向线条使用
final
hideLine bool
隐藏线条,使用纯文本分割
final
isDashed bool
是否为虚线
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin EdgeInsetsGeometry?
外部填充
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
文本字符串,使用默认样式
final
widget Widget?
中间控件,可自定义样式
final
width double?
宽度,需要竖向线条时使用
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited